@@ -64,7 +64,7 @@ docdb_create.src_couchdb <- function(src, key, value, ...) {
   # convert into target list
 
   # data frame
-  if (class(value) == "data.frame") {
+  if (isa(value, "data.frame")) {
     if (is.na(match("_id", names(value)))) {
       # if no _id column
       if (!identical(rownames(value),
@@ -78,7 +78,7 @@ docdb_create.src_couchdb <- function(src, key, value, ...) {
   } # if data.frame
 
   # convert JSON string to list
-  if (class(value) == "character") {
+  if (isa(value, "character")) {
     if ((length(value)  == 1L) &&
         (isUrl(value) || isFile(value))) {
       # read ndjson file or url (does not work with jsonify)
@@ -94,7 +94,7 @@ docdb_create.src_couchdb <- function(src, key, value, ...) {
   }
 
   # mangle lists
-  if (class(value) == "list") {
+  if (isa(value, "list")) {
     if (all(sapply(lapply(value, "[[", "_id"), is.null))) {
       # add canonical _id's
       value <- lapply(value, function(i) c(
@@ -139,7 +139,7 @@ docdb_create.src_elastic <- function(src, key, value, ...) {
   # body of your documents, and map this field as a keyword field that has [doc_values] enabled
 
   # data frame
-  if (class(value) == "data.frame") {
+  if (isa(value, "data.frame")) {
     if (is.na(match("_id", names(value)))) {
       # if no _id column
       if (!identical(rownames(value),
@@ -159,7 +159,7 @@ docdb_create.src_elastic <- function(src, key, value, ...) {
   } # if data.frame
 
   # convert JSON string to list
-  if (class(value) == "character") {
+  if (isa(value, "character")) {
 
     # since cocument IDs cannot be passed in
     # with files, create list from file
@@ -178,7 +178,7 @@ docdb_create.src_elastic <- function(src, key, value, ...) {
   }
 
   # mangle lists
-  if (class(value) == "list") {
+  if (isa(value, "list")) {
     if (all(sapply(lapply(value, "[[", "_id"), is.null))) {
       # add canonical _id's
       docids <- uuid::UUIDgenerate(use.time = TRUE, n = length(value))
@@ -230,7 +230,7 @@ docdb_create.src_mongo <- function(src, key, value, ...) {
   if (docdb_exists(src, key, value, ...)) existsMessage(key)
 
   # directly import ndjson file
-  if ((class(value) == "character") &&
+  if ((isa(value, "character")) &&
       (length(value)  == 1L) &&
       (isUrl(value) || isFile(value))) {
 
@@ -255,12 +255,12 @@ docdb_create.src_mongo <- function(src, key, value, ...) {
 
     # since mongolite does not accept valid JSON strings
     # that come as an one-element array, convert to list
-    if (class(value) == "character") {
+    if (isa(value, "character")) {
       value <- jsonify::from_json(value, simplify = FALSE)
     }
 
     # mongolite uses _id columns in dataframes as object _id's:
-    if (class(value) == "data.frame") {
+    if (isa(value, "data.frame")) {
       if (is.na(match("_id", names(value)))) {
         # if no _id column
         if (!identical(rownames(value),
@@ -281,7 +281,7 @@ docdb_create.src_mongo <- function(src, key, value, ...) {
     } # if data.frame
 
     # convert lists (incl. from previous step) to NDJSON
-    if (class(value) == "list") {
+    if (isa(value, "list")) {
       # add canonical _id's
       if ((!is.null(names(value)) && !any(names(value) == "_id")) &&
           !any(sapply(value, function(i) any(names(i) == "_id")))
@@ -353,13 +353,13 @@ docdb_create.src_sqlite <- function(src, key, value, ...) {
   }
 
   # convert lists to json
-  if (class(value) == "list") {
+  if (isa(value, "list")) {
     value <- jsonlite::toJSON(value, auto_unbox = TRUE, digits = NA)
   }
 
   # convert JSON string to data frame
-  if (class(value) == "character" ||
-      class(value) == "json") {
+  if (isa(value, "character") ||
+      isa(value, "json")) {
     # target is data frame for next section
 
     # convert ndjson file or json string to data frame
@@ -375,7 +375,7 @@ docdb_create.src_sqlite <- function(src, key, value, ...) {
     }
 
     # process if value remained a list
-    if (class(value) == "list") {
+    if (isa(value, "list")) {
 
       # any _id (would be in top level of list)
       ids <- value[["_id"]]
@@ -398,7 +398,7 @@ docdb_create.src_sqlite <- function(src, key, value, ...) {
   }
 
   # data frame
-  if (class(value) == "data.frame") {
+  if (isa(value, "data.frame")) {
     #
     if (is.na(match("_id", names(value)))) {
       # if no _id column
@@ -426,7 +426,7 @@ docdb_create.src_sqlite <- function(src, key, value, ...) {
       value <- value[, c("_id", "json"), drop = FALSE]
     }
     #
-    if (class(value[["_id"]]) == "list") {
+    if (isa(value[["_id"]], "list")) {
       # in case fromJSON created the _id column as list
       value[["_id"]] <- unlist(value[["_id"]])
     }
@@ -460,7 +460,7 @@ docdb_create.src_sqlite <- function(src, key, value, ...) {
 #' @export
 docdb_create.src_postgres <- function(src, key, value, ...) {
 
-  # reference: https://www.sqlite.org/json1.html
+  # reference: https://www.postgresql.org/docs/current/datatype-json.html
 
   # if table does not exist, create one
   if (!docdb_exists(src, key, ...)) {
@@ -486,13 +486,13 @@ docdb_create.src_postgres <- function(src, key, value, ...) {
   }
 
   # convert lists to json
-  if (class(value) == "list") {
+  if (isa(value, "list")) {
     value <- jsonlite::toJSON(value, auto_unbox = TRUE, digits = NA)
   }
 
   # convert JSON string to data frame
-  if (class(value) == "character" ||
-      class(value) == "json") {
+  if (isa(value, "character") ||
+      isa(value, "json")) {
     # target is data frame for next section
 
     # convert ndjson file or json string to data frame
@@ -508,13 +508,13 @@ docdb_create.src_postgres <- function(src, key, value, ...) {
     }
 
     # process if value remained a list
-    if (class(value) == "list") {
+    if (isa(value, "list")) {
 
       # any _id (would be in top level of list)
       ids <- value[["_id"]]
-      # remove _id's
+      # remove _id's from list
       if (length(ids)) value[["_id"]] <- NULL
-      # change back to json
+      # change list back to json
       value <- as.character(
         jsonlite::toJSON(
           value,
@@ -531,7 +531,7 @@ docdb_create.src_postgres <- function(src, key, value, ...) {
   }
 
   # data frame
-  if (class(value) == "data.frame") {
+  if (isa(value, "data.frame")) {
     #
     if (is.na(match("_id", names(value)))) {
       # if no _id column
@@ -559,7 +559,7 @@ docdb_create.src_postgres <- function(src, key, value, ...) {
       value <- value[, c("_id", "json"), drop = FALSE]
     }
     #
-    if (class(value[["_id"]]) == "list") {
+    if (isa(value[["_id"]], "list")) {
       # in case fromJSON created the _id column as list
       value[["_id"]] <- unlist(value[["_id"]])
     }
